summaryrefslogtreecommitdiffstats
path: root/juk/tagtransactionmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/tagtransactionmanager.h')
-rw-r--r--juk/tagtransactionmanager.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/juk/tagtransactionmanager.h b/juk/tagtransactionmanager.h
index 7f8ef8d0..7ea38f96 100644
--- a/juk/tagtransactionmanager.h
+++ b/juk/tagtransactionmanager.h
@@ -40,7 +40,7 @@ class TagTransactionAtom
/**
* Copy constructor. This takes ownership of the m_tag pointer, so the
* object being copied no longer has access to the tag. This function also
- * exists mainly for QValueList's benefit.
+ * exists mainly for TQValueList's benefit.
*
* @param other The TagTransactionAtom to copy.
*/
@@ -103,17 +103,18 @@ typedef TQValueList<TagTransactionAtom> TagAlterationList;
*
* @author Michael Pyne <michael.pyne@kdemail.net>
*/
-class TagTransactionManager : public QObject
+class TagTransactionManager : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs a TagTransactionManager, owned by @p parent.
*
* @param parent The parent TQWidget.
*/
- TagTransactionManager(TQWidget *parent = 0);
+ TagTransactionManager(TQWidget *tqparent = 0);
/**
* Returns the global TagTransactionManager instance.
@@ -137,13 +138,13 @@ class TagTransactionManager : public QObject
* object doesn't have a decent copy constructor.
*
* @param tag The Tag to duplicate.
- * @param fileName The filename to assign to the tag. If TQString::null
+ * @param fileName The filename to assign to the tag. If TQString()
* (the default) is passed, the filename of the existing tag is
* used.
* @bug Tag should have a correct copy ctor and assignment operator.
* @return The duplicate Tag.
*/
- static Tag *duplicateTag(const Tag *tag, const TQString &fileName = TQString::null);
+ static Tag *duplicateTag(const Tag *tag, const TQString &fileName = TQString());
/**
* Commits the changes to the PlaylistItems. It is important that the
@@ -103,17 +103,18 @@ typedef TQValueList<TagTransactionAtom> TagAlterationList;
public:
/**
- * Constructs a TagTransactionManager, owned by @p parent.
+ * Constructs a TagTransactionManager, owned by @p tqparent.
*
@@ -103,17 +103,18 @@ typedef TQValueList<TagTransactionAtom> TagAlterationList;
*
- * @param parent The parent TQWidget.
+ * @param tqparent The tqparent TQWidget.
*/